Package: qiimer
License: GPL (>= 2)
Maintainer: Kyle Bittinger <kylebittinger@gmail.com>
Title: Work with QIIME Output Files in R
Author: Kyle Bittinger <kylebittinger@gmail.com>
Description: Open QIIME output files in R, compute statistics, and
    create plots from the data.
Version: 0.9.4
URL: http://www.r-project.org
Date: 2015-12-27
Imports: grDevices, pheatmap, stats, utils
Suggests: testthat, biom
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2015-12-27 21:21:36 UTC; bittingerk
Repository: CRAN
Date/Publication: 2015-12-28 00:01:50
Built: R 3.4.1; ; 2018-10-12 07:02:05 UTC; windows
