# Generated by roxygen2: do not edit by hand

export(biom_raw_data)
export(biom_taxonomy)
export(dist_get)
export(dist_groups)
export(dist_subset)
export(make_otu_table)
export(otu_heatmap)
export(rarefaction_stats)
export(read_blast_table)
export(read_qiime_distmat)
export(read_qiime_mapping_file)
export(read_qiime_otu_mapping)
export(read_qiime_otu_table)
export(read_qiime_rarefaction)
export(saturated_rainbow)
export(simplify_assignments)
export(split_assignments)
export(taxonomic_ranks)
import(grDevices)
import(pheatmap)
import(stats)
import(utils)
